@@ -1,16 +1,17 @@
 package appupdate
 
 import (
+	"bufio"
 	"bytes"
 	"context"
-	"github.com/atinylittleshell/gsh/internal/filesystem"
+	"fmt"
 	"io"
+	"os"
 	"strings"
 
 	"github.com/Masterminds/semver/v3"
 	"github.com/atinylittleshell/gsh/internal/core"
-	"github.com/atinylittleshell/gsh/internal/styles"
-	"github.com/atinylittleshell/gsh/pkg/gline"
+	"github.com/atinylittleshell/gsh/internal/filesystem"
 	"github.com/creativeprojects/go-selfupdate"
 	"go.uber.org/zap"
 )
@@ -19,7 +20,6 @@ func HandleSelfUpdate(
 	currentVersion string,
 	logger *zap.Logger,
 	fs filesystem.FileSystem,
-	prompter core.UserPrompter,
 	updater Updater,
 ) chan string {
 	resultChannel := make(chan string)
@@ -32,7 +32,7 @@ func HandleSelfUpdate(
 	}
 
 	// Check if we have previously detected a newer version
-	updateToLatestVersion(currentSemVer, logger, fs, prompter, updater)
+	updateToLatestVersion(currentSemVer, logger, fs, updater)
 
 	// Check for newer versions from remote repository
 	go fetchAndSaveLatestVersion(resultChannel, logger, fs, updater)
@@ -56,7 +56,7 @@ func readLatestVersion(fs filesystem.FileSystem) string {
 	return strings.TrimSpace(buf.String())
 }
 
-func updateToLatestVersion(currentSemVer *semver.Version, logger *zap.Logger, fs filesystem.FileSystem, prompter core.UserPrompter, updater Updater) {
+func updateToLatestVersion(currentSemVer *semver.Version, logger *zap.Logger, fs filesystem.FileSystem, updater Updater) {
 	latestVersion := readLatestVersion(fs)
 	if latestVersion == "" {
 		return
@@ -71,18 +71,28 @@ func updateToLatestVersion(currentSemVer *semver.Version, logger *zap.Logger, fs
 		return
 	}
 
-	confirm, err := prompter.Prompt(
-		styles.AGENT_QUESTION("New version of gsh available. Update now? (Y/n) "),
-		[]string{},
-		latestVersion,
-		nil,
-		nil,
-		nil,
-		logger,
-		gline.NewOptions(),
-	)
+	// Check for major version boundary - don't auto-update across major versions
+	if latestSemVer.Major() > currentSemVer.Major() {
+		logger.Info("major version update available",
+			zap.String("current", currentSemVer.String()),
+			zap.String("latest", latestSemVer.String()),
+			zap.String("info", "Major version updates require manual upgrade. See https://github.com/atinylittleshell/gsh for migration guide."))
+		return
+	}
 
-	if strings.ToLower(confirm) == "n" {
+	// Prompt user for confirmation
+	fmt.Printf("\nNew version of gsh available: %s (current: %s)\n", latestVersion, currentSemVer.String())
+	fmt.Print("Update now? (Y/n): ")
+
+	reader := bufio.NewReader(os.Stdin)
+	confirm, err := reader.ReadString('\n')
+	if err != nil {
+		logger.Warn("failed to read user input", zap.Error(err))
+		return
+	}
+
+	confirm = strings.TrimSpace(strings.ToLower(confirm))
+	if confirm == "n" || confirm == "no" {
 		return
 	}
 
@@ -128,14 +138,15 @@ func fetchAndSaveLatestVersion(resultChannel chan string, logger *zap.Logger, fs
 		return
 	}
 
+	// Note: We save the latest version even if it's a major version bump
+	// This allows updateToLatestVersion to show an info message about the major update
 	recordFilePath := core.LatestVersionFile()
 	file, err := fs.Create(recordFilePath)
-	defer file.Close()
-
 	if err != nil {
 		logger.Error("failed to save latest version", zap.Error(err))
 		return
 	}
+	defer file.Close()
 
 	_, err = file.WriteString(latest.Version())
 	if err != nil {
