@@ -4,9 +4,9 @@ import (
 	"database/sql"
 	"fmt"
 	"os"
+	"slices"
 	"time"
 
-	"github.com/atinylittleshell/gsh/pkg/reverse"
 	"github.com/glebarez/sqlite"
 	"gorm.io/gorm"
 )
@@ -32,7 +32,10 @@ func NewHistoryManager(dbFilePath string) (*HistoryManager, error) {
 		return nil, err
 	}
 
-	db.AutoMigrate(&HistoryEntry{})
+	if err := db.AutoMigrate(&HistoryEntry{}); err != nil {
+		fmt.Fprintf(os.Stderr, "error auto-migrating database schema: %v\n", err)
+		return nil, err
+	}
 
 	return &HistoryManager{
 		db: db,
@@ -75,7 +78,7 @@ func (historyManager *HistoryManager) GetRecentEntries(directory string, limit i
 		return nil, result.Error
 	}
 
-	reverse.Reverse(entries)
+	slices.Reverse(entries)
 	return entries, nil
 }
 
@@ -111,4 +114,19 @@ func (historyManager *HistoryManager) GetRecentEntriesByPrefix(prefix string, li
 	}
 
 	return entries, nil
-}
\ No newline at end of file
+}
+
+// SearchHistory searches for history entries containing the given substring.
+// Returns entries in reverse chronological order (most recent first).
+func (historyManager *HistoryManager) SearchHistory(query string, limit int) ([]HistoryEntry, error) {
+	var entries []HistoryEntry
+	result := historyManager.db.Where("command LIKE ?", "%"+query+"%").
+		Order("created_at desc").
+		Limit(limit).
+		Find(&entries)
+	if result.Error != nil {
+		return nil, result.Error
+	}
+
+	return entries, nil
+}
